@@ -7,7 +7,7 @@
 
 class Config;
 class KPushButton;
-class KListBox;
+class TDEListBox;
 
 /**
 * @short The page for configuring the environment
@@ -17,7 +17,7 @@ class KListBox;
 class ConfigEnvironmentPage : public ConfigPageBase
 {
     Q_OBJECT
-  TQ_OBJECT
+  
 public:
     /**
      * Default Constructor
@@ -30,13 +30,13 @@ public:
     virtual ~ConfigEnvironmentPage();
 
 private:
-    KListBox* lDirectories;
+    TDEListBox* lDirectories;
     KPushButton* pDirUp;
     KPushButton* pDirDown;
     KPushButton* pAddDirectory;
     KPushButton* pRemoveDirectory;
-    KListBox* lFoundPrograms;
-    KListBox* lNotFoundPrograms;
+    TDEListBox* lFoundPrograms;
+    TDEListBox* lNotFoundPrograms;
 
     Config* config;
 
