@@ -14,11 +14,11 @@
 
 #include <math.h>
 
-#include <klocale.h>
-#include <kglobal.h>
+#include <tdelocale.h>
+#include <tdeglobal.h>
 //#include <kdebug.h>
-#include <ktempfile.h>
-#include <kio/job.h>
+#include <tdetempfile.h>
+#include <tdeio/job.h>
 //#include <kprocess.h>
 #include <kstandarddirs.h>
 
@@ -98,15 +98,15 @@ void Convert::get( ConvertItem* item )
         logger->log( item->logID, "cp \"" + source.path() + "\" \"" + destination.path() + "\"" );
 
         item->convertProcess->setPriority( config->data.general.priority );
-        item->convertProcess->start( KProcess::NotifyOnExit, KProcess::AllOutput );
+        item->convertProcess->start( TDEProcess::NotifyOnExit, TDEProcess::AllOutput );
     }
     else {
-        item->moveJob = new KIO::FileCopyJob( source, destination, -1, false, true, false, false );
-        connect( item->moveJob, TQT_SIGNAL(percent(KIO::Job*,unsigned long)),
-                this, TQT_SLOT(moveProgress(KIO::Job*,unsigned long))
+        item->moveJob = new TDEIO::FileCopyJob( source, destination, -1, false, true, false, false );
+        connect( item->moveJob, TQT_SIGNAL(percent(TDEIO::Job*,unsigned long)),
+                this, TQT_SLOT(moveProgress(TDEIO::Job*,unsigned long))
                 );
-        connect( item->moveJob, TQT_SIGNAL(result(KIO::Job*)),
-                this, TQT_SLOT(moveFinished(KIO::Job*))
+        connect( item->moveJob, TQT_SIGNAL(result(TDEIO::Job*)),
+                this, TQT_SLOT(moveFinished(TDEIO::Job*))
                 );
     }
 }
@@ -139,15 +139,15 @@ void Convert::getCorrection( ConvertItem* item )
         logger->log( item->logID, "cp \"" + source.path() + "\" \"" + destination.path() + "\"" );
 
         item->convertProcess->setPriority( config->data.general.priority );
-        item->convertProcess->start( KProcess::NotifyOnExit, KProcess::AllOutput );
+        item->convertProcess->start( TDEProcess::NotifyOnExit, TDEProcess::AllOutput );
     }
     else {
-        item->moveJob = new KIO::FileCopyJob( source, destination, -1, false, true, false, false );
-        connect( item->moveJob, TQT_SIGNAL(percent(KIO::Job*,unsigned long)),
-                this, TQT_SLOT(moveProgress(KIO::Job*,unsigned long))
+        item->moveJob = new TDEIO::FileCopyJob( source, destination, -1, false, true, false, false );
+        connect( item->moveJob, TQT_SIGNAL(percent(TDEIO::Job*,unsigned long)),
+                this, TQT_SLOT(moveProgress(TDEIO::Job*,unsigned long))
                 );
-        connect( item->moveJob, TQT_SIGNAL(result(KIO::Job*)),
-                this, TQT_SLOT(moveFinished(KIO::Job*))
+        connect( item->moveJob, TQT_SIGNAL(result(TDEIO::Job*)),
+                this, TQT_SLOT(moveFinished(TDEIO::Job*))
                 );
     }
 }
@@ -190,12 +190,12 @@ void Convert::rip( ConvertItem* item )
         item->fileListItem->setText( fileList->columnByName(i18n("State")), i18n("Ripping")+"... 00 %" );
         item->fileListItem->ripping = true;
 
-        item->moveJob = new KIO::FileCopyJob( source, dest, -1, false, true, false, false );
-        connect( item->moveJob, TQT_SIGNAL(percent(KIO::Job*,unsigned long)),
-                   this, TQT_SLOT(moveProgress(KIO::Job*,unsigned long))
+        item->moveJob = new TDEIO::FileCopyJob( source, dest, -1, false, true, false, false );
+        connect( item->moveJob, TQT_SIGNAL(percent(TDEIO::Job*,unsigned long)),
+                   this, TQT_SLOT(moveProgress(TDEIO::Job*,unsigned long))
                  );
-        connect( item->moveJob, TQT_SIGNAL(result(KIO::Job*)),
-                   this, TQT_SLOT(moveFinished(KIO::Job*))
+        connect( item->moveJob, TQT_SIGNAL(result(TDEIO::Job*)),
+                   this, TQT_SLOT(moveFinished(TDEIO::Job*))
                  );
     }
     else {
@@ -261,7 +261,7 @@ void Convert::rip( ConvertItem* item )
         item->fileListItem->ripping = true;
 
         item->convertProcess->setPriority( config->data.general.priority );
-        item->convertProcess->start( KProcess::NotifyOnExit, KProcess::AllOutput );
+        item->convertProcess->start( TDEProcess::NotifyOnExit, TDEProcess::AllOutput );
     }
 }
 
@@ -314,7 +314,7 @@ void Convert::decode( ConvertItem* item )
     item->fileListItem->setText( fileList->columnByName(i18n("State")), i18n("Decoding")+"... 00 %" );
 
     item->convertProcess->setPriority( config->data.general.priority );
-    item->convertProcess->start( KProcess::NotifyOnExit, KProcess::AllOutput );
+    item->convertProcess->start( TDEProcess::NotifyOnExit, TDEProcess::AllOutput );
 }
 
 void Convert::encode( ConvertItem* item )
@@ -420,7 +420,7 @@ void Convert::encode( ConvertItem* item )
                 //t_int -= t_int%plugin->enc.quality.step;
                 sQuality = TQString::number( t_int );
             }
-            if( plugin->enc.bin == "oggenc" ) sQuality.replace(TQChar('.'),KGlobal::locale()->decimalSymbol()); // HACK make oggenc usable with all langauges
+            if( plugin->enc.bin == "oggenc" ) sQuality.replace(TQChar('.'),TDEGlobal::locale()->decimalSymbol()); // HACK make oggenc usable with all langauges
             else if( plugin->enc.lossy.quality.separator != '.' ) sQuality.replace(TQChar('.'),plugin->enc.lossy.quality.separator);
         }
         else {
@@ -555,7 +555,7 @@ void Convert::encode( ConvertItem* item )
     item->fileListItem->setText( fileList->columnByName(i18n("State")), i18n("Encoding")+"... 00 %" );
 
     item->convertProcess->setPriority( config->data.general.priority );
-    item->convertProcess->start( KProcess::NotifyOnExit, KProcess::AllOutput );
+    item->convertProcess->start( TDEProcess::NotifyOnExit, TDEProcess::AllOutput );
 }
 
 void Convert::replaygain( ConvertItem* item )
@@ -631,15 +631,15 @@ void Convert::put( ConvertItem* item )
         logger->log( item->logID, "cp \"" + source.path() + "\" \"" + destination.path() + "\"" );
 
         item->convertProcess->setPriority( config->data.general.priority );
-        item->convertProcess->start( KProcess::NotifyOnExit, KProcess::AllOutput );
+        item->convertProcess->start( TDEProcess::NotifyOnExit, TDEProcess::AllOutput );
     }
     else {
-        item->moveJob = new KIO::FileCopyJob( source, destination, -1, false, false, false, false );
-        connect( item->moveJob, TQT_SIGNAL(percent(KIO::Job*,unsigned long)),
-                this, TQT_SLOT(moveProgress(KIO::Job*,unsigned long))
+        item->moveJob = new TDEIO::FileCopyJob( source, destination, -1, false, false, false, false );
+        connect( item->moveJob, TQT_SIGNAL(percent(TDEIO::Job*,unsigned long)),
+                this, TQT_SLOT(moveProgress(TDEIO::Job*,unsigned long))
                 );
-        connect( item->moveJob, TQT_SIGNAL(result(KIO::Job*)),
-                this, TQT_SLOT(moveFinished(KIO::Job*))
+        connect( item->moveJob, TQT_SIGNAL(result(TDEIO::Job*)),
+                this, TQT_SLOT(moveFinished(TDEIO::Job*))
                 );
     }
 }
@@ -670,15 +670,15 @@ void Convert::putCorrection( ConvertItem* item )
         logger->log( item->logID, "cp \"" + source.path() + "\" \"" + destination.path() + "\"" );
 
         item->convertProcess->setPriority( config->data.general.priority );
-        item->convertProcess->start( KProcess::NotifyOnExit, KProcess::AllOutput );
+        item->convertProcess->start( TDEProcess::NotifyOnExit, TDEProcess::AllOutput );
     }
     else {
-        item->moveJob = new KIO::FileCopyJob( source, destination, -1, false, false, false, false );
-        connect( item->moveJob, TQT_SIGNAL(percent(KIO::Job*,unsigned long)),
-                this, TQT_SLOT(moveProgress(KIO::Job*,unsigned long))
+        item->moveJob = new TDEIO::FileCopyJob( source, destination, -1, false, false, false, false );
+        connect( item->moveJob, TQT_SIGNAL(percent(TDEIO::Job*,unsigned long)),
+                this, TQT_SLOT(moveProgress(TDEIO::Job*,unsigned long))
                 );
-        connect( item->moveJob, TQT_SIGNAL(result(KIO::Job*)),
-                this, TQT_SLOT(moveFinished(KIO::Job*))
+        connect( item->moveJob, TQT_SIGNAL(result(TDEIO::Job*)),
+                this, TQT_SLOT(moveFinished(TDEIO::Job*))
                 );
     }
 }
@@ -705,7 +705,7 @@ void Convert::executeUserScript( ConvertItem* item )
     logger->log( item->logID, userscript + " \"" + source.path() + "\" \"" + destination.path() + "\"" );
 
     item->convertProcess->setPriority( config->data.general.priority );
-    item->convertProcess->start( KProcess::NotifyOnExit, KProcess::AllOutput );
+    item->convertProcess->start( TDEProcess::NotifyOnExit, TDEProcess::AllOutput );
 }
 
 void Convert::executeNextStep( ConvertItem* item )
@@ -830,7 +830,7 @@ void Convert::executeNextStep( ConvertItem* item )
     }
 }
 
-void Convert::moveProgress( KIO::Job* job, unsigned long percent )
+void Convert::moveProgress( TDEIO::Job* job, unsigned long percent )
 {
     // search the item list for our item
     for( TQValueList<ConvertItem*>::Iterator item = items.begin(); item != items.end(); item++ ) {
@@ -840,7 +840,7 @@ void Convert::moveProgress( KIO::Job* job, unsigned long percent )
     }
 }
 
-void Convert::moveFinished( KIO::Job* job )
+void Convert::moveFinished( TDEIO::Job* job )
 {
     // search the item list for our item
     for( TQValueList<ConvertItem*>::Iterator item = items.begin(); item != items.end(); item++ ) {
@@ -924,7 +924,7 @@ void Convert::moveFinished( KIO::Job* job )
     }
 }
 
-void Convert::processOutput( KProcess* proc, char* data, int )
+void Convert::processOutput( TDEProcess* proc, char* data, int )
 {
     int iPercent = 0, iTime = 0, iPos = 0, iNum = 0;
 
@@ -1083,7 +1083,7 @@ void Convert::processOutput( KProcess* proc, char* data, int )
     }
 }
 
-void Convert::processExit( KProcess* proc )
+void Convert::processExit( TDEProcess* proc )
 {
     // search the item list for our item
     for( TQValueList<ConvertItem*>::Iterator item = items.begin(); item != items.end(); item++ ) {
@@ -1316,15 +1316,15 @@ void Convert::add( FileListItem* item )
     (*newItem)->correctionOutputExtension = TQString()();*/
 
     // connect convertProcess of our new item with the slots of Convert
-    (*newItem)->convertProcess = new KProcess();
-    connect( (*newItem)->convertProcess, TQT_SIGNAL(receivedStdout(KProcess*,char*,int)),
-               this, TQT_SLOT(processOutput(KProcess*,char*,int))
+    (*newItem)->convertProcess = new TDEProcess();
+    connect( (*newItem)->convertProcess, TQT_SIGNAL(receivedStdout(TDEProcess*,char*,int)),
+               this, TQT_SLOT(processOutput(TDEProcess*,char*,int))
              );
-    connect( (*newItem)->convertProcess, TQT_SIGNAL(receivedStderr(KProcess*,char*,int)),
-               this, TQT_SLOT(processOutput(KProcess*,char*,int))
+    connect( (*newItem)->convertProcess, TQT_SIGNAL(receivedStderr(TDEProcess*,char*,int)),
+               this, TQT_SLOT(processOutput(TDEProcess*,char*,int))
              );
-    connect( (*newItem)->convertProcess, TQT_SIGNAL(processExited(KProcess*)),
-               this, TQT_SLOT(processExit(KProcess*))
+    connect( (*newItem)->convertProcess, TQT_SIGNAL(processExited(TDEProcess*)),
+               this, TQT_SLOT(processExit(TDEProcess*))
              );
 
     // NOTE the tempInFile is also created if the file is a audio cd track
@@ -1486,7 +1486,7 @@ void Convert::remove( ConvertItem* item, int state )
             paramSplinter.replace( "%o", item->outputFilePathName );
             notify << paramSplinter;
         }
-        notify.start( KProcess::DontCare );
+        notify.start( TDEProcess::DontCare );
     }
 
     item->fileListItem->converting = false;
@@ -1592,7 +1592,7 @@ void Convert::updateProgressIndicator()
 
 // void Convert::priorityChanged( int priority )
 // { // FIXME setting a higher priority does not work
-//     KProcess pChangePriority;
+//     TDEProcess pChangePriority;
 // 
 //     for( TQValueList<ConvertItem*>::Iterator it = items.begin(); it != items.end(); it++ ) {
 //         if( (*it)->convertProcess->isRunning() ) {
@@ -1607,7 +1607,7 @@ void Convert::updateProgressIndicator()
 //             pChangePriority << pid;
 //             //TQString cmd;
 //             //cmd.sprintf( "renice %i %i",  );
-//             pChangePriority.start( KProcess::Block );
+//             pChangePriority.start( TDEProcess::Block );
 //         }
 //     }
 // }
